.. -*- coding: utf-8 -*-

.. include:: 5.0.rst
.. include:: 4.10.rst
.. include:: 4.9.rst
.. include:: 4.8.rst
.. include:: 4.7.rst
.. include:: 4.6.rst
.. include:: 4.5.rst
.. include:: 4.4.rst
.. include:: 4.3.rst
.. include:: 4.2.rst
.. include:: 4.1.rst
.. include:: 4.0.rst

.. include:: 3.38.rst
.. include:: 3.37.rst
.. include:: 3.36.rst

.. include:: 3.35.rst
.. include:: 3.34.rst
.. include:: 3.33.rst
.. include:: 3.32.rst
.. include:: 3.31.rst
.. include:: 3.30.rst
.. include:: 3.29.rst
.. include:: 3.28.rst
.. include:: 3.27.rst
.. include:: 3.26.rst
.. include:: 3.25.rst
.. include:: 3.24.rst
.. include:: 3.23.rst
.. include:: 3.22.rst
.. include:: 3.21.rst
.. include:: 3.20.rst
.. include:: 3.19.rst
.. include:: 3.18.rst
.. include:: 3.17.rst
.. include:: 3.16.rst
.. include:: 3.15.rst
.. include:: 3.14.rst
